|discord| |qgroup| |py_v| |ruff| |docs_status|

Comprehensive AI Toolkit for Multimodal Learning and Cross-Platform Robotics |Structure|
========================================================================================

.. index-start
Welcome to iamai, a powerful and comprehensive AI toolkit that seamlessly integrates multimodal machine learning capabilities with advanced tools for cross-platform robot development!

  🌍 This library is designed to provide developers with a unified solution for creating intelligent systems that span multiple modalities and operate across diverse platforms.

- 🦀 Rust based tool, fast and simple.
- 🎪 Interactive docs & demos
- 🕶 Seamless migration: Works for both Rasa and GPT and more...
- ⚡ Fully tree shakeable: Only take what you want, bundle size
- 🔩 Flexible: Configurable event filters and targets
- 🔌 Optional Add-ons: Apscheduler, etc.
- 👍 Cross-platform: dingtalk etc.

.. index-end

First of all, in the field of machine learning, we drew inspiration from the excellent design of `Hugging Face`_'s `transformers`_ for the use of pre-trained models. We would like to express our gratitude to the authors of Hugging Face and their open-source community.

Secondly, regarding the cross-platform robot framework, it is primarily based on `st`_'s `alicebot`_. We have made numerous adaptations to make it compatible with machine learning. We would like to thank the st and alicebot open-source communities for their contributions.

To avoid any potential disputes or misunderstandings, we have listed the licenses of the projects we have used and express our gratitude towards them. Please see `credits.pdf`_.

*Cite This Software*

.. code:: bibtex

   @inproceedings{Hsiang_IamAI_A_Python_2023,
   author = {Hsiang, Nianian},
   month = aug,
   pages = {1--10},
   publisher = {Association for AICMUniversity},
   title = {{IamAI: A Python Library for Artificial Intelligence and RobotFramework}},
   url = {https://pub.aicmu.ac.cn},
   year = {2023}
   }

----

`MIT`_ © 2023-PRESENT `Retro for Wut?`_.

|FOSSA Status|

|FOSSA Badge|

.. |Structure| image:: https://images.repography.com/40962158/retrofor/iamai/structure/afEhYzXo83AMGRNy9EzPPQcX9ECBKj2gOPhvmpzMFSg/DQMxDEhfNZdq6zFhjPa1G61Bg9g-DRhQiwNY-W2ZHVE_table.svg
   :width: 60
.. _`Hugging Face`: https://huggingface.co
.. _`transformers`: https://github.com/huggingface/transformers
.. _`st`: https://github.com/st1020
.. _`alicebot`: https://github.com/AliceBotProject/alicebot
.. _`credits.pdf`: ./docs/_static/assets/credits.pdf
.. _`MIT`: https://github.com/retrofor/iamai/blob/master/COPYING
.. _`Retro for Wut?`: https://github.com/retrofor
.. |FOSSA Status| image:: https://app.fossa.com/api/projects/git%2Bgithub.com%2Fretrofor%2Fiamai.svg?type=shield
   :target: https://app.fossa.com/projects/git%2Bgithub.com%2Fretrofor%2Fiamai?ref=badge_shield
.. |FOSSA Badge| image:: https://app.fossa.com/api/projects/git%2Bgithub.com%2Fretrofor%2Fiamai.svg?type=large
   :target: https://app.fossa.com/projects/git%2Bgithub.com%2Fretrofor%2Fiamai?ref=badge_large
.. |docs| image:: https://readthedocs.org/projects/iamai/badge/?version=latest
   :target: https://iamai.is-a.dev/en/latest/?badge=latest
.. |ruff| image:: https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json
   :target: https://github.com/astral-sh/ruff
   :alt: Ruff
.. |discord| image:: https://img.shields.io/discord/1063871387527303188?style=flat-square
   :target: https://discord.gg/9vG9352RXS
.. |qgroup| image:: https://img.shields.io/badge/-QQ群%20761859776-002FA7?style=flat-square&logo=Tencent QQ&logoColor=white
   :target: https://jq.qq.com/?_wv=1027&k=OOUmgrqx
.. |py_v| image:: https://img.shields.io/badge/stable%20version-v0.0.4%20Siamese-blue?style=flat-square&logo=python
   :target: https://pypi.python.org/pypi/iamai
.. |docs_status| image:: https://readthedocs.org/projects/iamai/badge/?version=latest
   :target: https://iamai.is-a.dev/en/latest/?badge=latest
